@@ -4,7 +4,7 @@
 # https://lvbag.github.io/BAG-API/Technische%20specificatie/#/Adres%20uitgebreid/zoekAdresUitgebreid
 # https://lvbag.github.io/BAG-API/Technische%20specificatie/
 import os
-from typing import List
+from typing import List, Optional
 
 import requests
 
@@ -59,8 +59,13 @@ def _get_extended_address_info(
         raise ConnectionError(f"Error: {response.status_code} {response.reason}")
 
 
-def _clean_bag_api_output(api_output: dict) -> List[dict]:
-    """Clean the api output to a more user friendly version."""
+def _clean_bag_api_output(api_output: dict) -> Optional[List[dict]]:
+    """Clean the api output to a more user friendly version.
+    """
+
+    # Check if the api output doesn't contains the key "_embedded"
+    if "_embedded" not in api_output:
+        return None
 
     items_to_keep = [
         "adresregel5",
@@ -99,19 +104,7 @@ def _clean_bag_api_output(api_output: dict) -> List[dict]:
                 new_dict[new_key] = new_dict.pop(old_key)
 
         # Change values to a more user friendly version
-        for key, value in new_dict.items():
-            # if value is an integer or float, convert to string
-            if isinstance(value, int) or isinstance(value, float):
-                new_dict[key] = str(value)
-            # if value is a list, with strings, integers and/or floats, convert to string
-            elif isinstance(value, list):
-                new_dict[key] = ", ".join([str(x) for x in value])
-            # if value is a dictionary, convert key and value to string
-            elif isinstance(value, dict):
-                new_dict[key] = ", ".join([f"{k}: {v}" for k, v in value.items()])
-            # if value is None, convert to empty string
-            elif value is None:
-                new_dict[key] = ""
+        _change_to_user_friendly_values(new_dict)
 
         # Add "toevoeging" to the dictionary
         new_dict["toevoeging"] = f"{new_dict['huisletter']}{new_dict['huisnummertoevoeging']}".strip()
@@ -122,6 +115,22 @@ def _clean_bag_api_output(api_output: dict) -> List[dict]:
     return adressen
 
 
+def _change_to_user_friendly_values(new_dict):
+    for key, value in new_dict.items():
+        # if value is an integer or float, convert to string
+        if isinstance(value, int) or isinstance(value, float):
+            new_dict[key] = str(value)
+        # if value is a list, with strings, integers and/or floats, convert to string
+        elif isinstance(value, list):
+            new_dict[key] = ", ".join([str(x) for x in value])
+        # if value is a dictionary, convert key and value to string
+        elif isinstance(value, dict):
+            new_dict[key] = ", ".join([f"{k}: {v}" for k, v in value.items()])
+        # if value is None, convert to empty string
+        elif value is None:
+            new_dict[key] = ""
+
+
 def get_zip_code_info(
     zip_code: str,
     house_number: str,
